@@ -17,15 +17,14 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_datasync.paginator import (
+from .literals import ObjectStorageServerProtocolType, S3StorageClassType
+from .paginator import (
     ListAgentsPaginator,
     ListLocationsPaginator,
     ListTagsForResourcePaginator,
     ListTaskExecutionsPaginator,
     ListTasksPaginator,
 )
-
-from .literals import ObjectStorageServerProtocol, S3StorageClass
 from .type_defs import (
     CreateAgentResponseTypeDef,
     CreateLocationEfsResponseTypeDef,
@@ -88,7 +87,7 @@ class Exceptions:
 
 class DataSyncClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -97,14 +96,14 @@ class DataSyncClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def cancel_task_execution(self, TaskExecutionArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
-        [Show boto3-stubs documentation](./client.md#cancel-task-execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
+        [Show boto3-stubs documentation](./client.md#cancel_task_execution)
         """
 
     def create_agent(
@@ -117,8 +116,8 @@ class DataSyncClient:
         SecurityGroupArns: List[str] = None,
     ) -> CreateAgentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.create_agent)
-        [Show boto3-stubs documentation](./client.md#create-agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.create_agent)
+        [Show boto3-stubs documentation](./client.md#create_agent)
         """
 
     def create_location_efs(
@@ -129,8 +128,8 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateLocationEfsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.create_location_efs)
-        [Show boto3-stubs documentation](./client.md#create-location-efs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.create_location_efs)
+        [Show boto3-stubs documentation](./client.md#create_location_efs)
         """
 
     def create_location_fsx_windows(
@@ -144,8 +143,8 @@ class DataSyncClient:
         Domain: str = None,
     ) -> CreateLocationFsxWindowsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
-        [Show boto3-stubs documentation](./client.md#create-location-fsx-windows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
+        [Show boto3-stubs documentation](./client.md#create_location_fsx_windows)
         """
 
     def create_location_nfs(
@@ -157,8 +156,8 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateLocationNfsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.create_location_nfs)
-        [Show boto3-stubs documentation](./client.md#create-location-nfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.create_location_nfs)
+        [Show boto3-stubs documentation](./client.md#create_location_nfs)
         """
 
     def create_location_object_storage(
@@ -167,15 +166,15 @@ class DataSyncClient:
         BucketName: str,
         AgentArns: List[str],
         ServerPort: int = None,
-        ServerProtocol: ObjectStorageServerProtocol = None,
+        ServerProtocol: ObjectStorageServerProtocolType = None,
         Subdirectory: str = None,
         AccessKey: str = None,
         SecretKey: str = None,
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateLocationObjectStorageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
-        [Show boto3-stubs documentation](./client.md#create-location-object-storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
+        [Show boto3-stubs documentation](./client.md#create_location_object_storage)
         """
 
     def create_location_s3(
@@ -183,13 +182,13 @@ class DataSyncClient:
         S3BucketArn: str,
         S3Config: "S3ConfigTypeDef",
         Subdirectory: str = None,
-        S3StorageClass: S3StorageClass = None,
+        S3StorageClass: S3StorageClassType = None,
         AgentArns: List[str] = None,
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateLocationS3ResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.create_location_s3)
-        [Show boto3-stubs documentation](./client.md#create-location-s3)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.create_location_s3)
+        [Show boto3-stubs documentation](./client.md#create_location_s3)
         """
 
     def create_location_smb(
@@ -204,8 +203,8 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateLocationSmbResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.create_location_smb)
-        [Show boto3-stubs documentation](./client.md#create-location-smb)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.create_location_smb)
+        [Show boto3-stubs documentation](./client.md#create_location_smb)
         """
 
     def create_task(
@@ -220,86 +219,86 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateTaskResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.create_task)
-        [Show boto3-stubs documentation](./client.md#create-task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.create_task)
+        [Show boto3-stubs documentation](./client.md#create_task)
         """
 
     def delete_agent(self, AgentArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.delete_agent)
-        [Show boto3-stubs documentation](./client.md#delete-agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.delete_agent)
+        [Show boto3-stubs documentation](./client.md#delete_agent)
         """
 
     def delete_location(self, LocationArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.delete_location)
-        [Show boto3-stubs documentation](./client.md#delete-location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.delete_location)
+        [Show boto3-stubs documentation](./client.md#delete_location)
         """
 
     def delete_task(self, TaskArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.delete_task)
-        [Show boto3-stubs documentation](./client.md#delete-task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.delete_task)
+        [Show boto3-stubs documentation](./client.md#delete_task)
         """
 
     def describe_agent(self, AgentArn: str) -> DescribeAgentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.describe_agent)
-        [Show boto3-stubs documentation](./client.md#describe-agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.describe_agent)
+        [Show boto3-stubs documentation](./client.md#describe_agent)
         """
 
     def describe_location_efs(self, LocationArn: str) -> DescribeLocationEfsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.describe_location_efs)
-        [Show boto3-stubs documentation](./client.md#describe-location-efs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.describe_location_efs)
+        [Show boto3-stubs documentation](./client.md#describe_location_efs)
         """
 
     def describe_location_fsx_windows(
         self, LocationArn: str
     ) -> DescribeLocationFsxWindowsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
-        [Show boto3-stubs documentation](./client.md#describe-location-fsx-windows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
+        [Show boto3-stubs documentation](./client.md#describe_location_fsx_windows)
         """
 
     def describe_location_nfs(self, LocationArn: str) -> DescribeLocationNfsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
-        [Show boto3-stubs documentation](./client.md#describe-location-nfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
+        [Show boto3-stubs documentation](./client.md#describe_location_nfs)
         """
 
     def describe_location_object_storage(
         self, LocationArn: str
     ) -> DescribeLocationObjectStorageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
-        [Show boto3-stubs documentation](./client.md#describe-location-object-storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
+        [Show boto3-stubs documentation](./client.md#describe_location_object_storage)
         """
 
     def describe_location_s3(self, LocationArn: str) -> DescribeLocationS3ResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.describe_location_s3)
-        [Show boto3-stubs documentation](./client.md#describe-location-s3)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.describe_location_s3)
+        [Show boto3-stubs documentation](./client.md#describe_location_s3)
         """
 
     def describe_location_smb(self, LocationArn: str) -> DescribeLocationSmbResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.describe_location_smb)
-        [Show boto3-stubs documentation](./client.md#describe-location-smb)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.describe_location_smb)
+        [Show boto3-stubs documentation](./client.md#describe_location_smb)
         """
 
     def describe_task(self, TaskArn: str) -> DescribeTaskResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.describe_task)
-        [Show boto3-stubs documentation](./client.md#describe-task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.describe_task)
+        [Show boto3-stubs documentation](./client.md#describe_task)
         """
 
     def describe_task_execution(
         self, TaskExecutionArn: str
     ) -> DescribeTaskExecutionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.describe_task_execution)
-        [Show boto3-stubs documentation](./client.md#describe-task-execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.describe_task_execution)
+        [Show boto3-stubs documentation](./client.md#describe_task_execution)
         """
 
     def generate_presigned_url(
@@ -310,16 +309,16 @@ class DataSyncClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def list_agents(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListAgentsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.list_agents)
-        [Show boto3-stubs documentation](./client.md#list-agents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.list_agents)
+        [Show boto3-stubs documentation](./client.md#list_agents)
         """
 
     def list_locations(
@@ -329,32 +328,32 @@ class DataSyncClient:
         Filters: List[LocationFilterTypeDef] = None,
     ) -> ListLocationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.list_locations)
-        [Show boto3-stubs documentation](./client.md#list-locations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.list_locations)
+        [Show boto3-stubs documentation](./client.md#list_locations)
         """
 
     def list_tags_for_resource(
         self, ResourceArn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def list_task_executions(
         self, TaskArn: str = None, MaxResults: int = None, NextToken: str = None
     ) -> ListTaskExecutionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.list_task_executions)
-        [Show boto3-stubs documentation](./client.md#list-task-executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.list_task_executions)
+        [Show boto3-stubs documentation](./client.md#list_task_executions)
         """
 
     def list_tasks(
         self, MaxResults: int = None, NextToken: str = None, Filters: List[TaskFilterTypeDef] = None
     ) -> ListTasksResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.list_tasks)
-        [Show boto3-stubs documentation](./client.md#list-tasks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.list_tasks)
+        [Show boto3-stubs documentation](./client.md#list_tasks)
         """
 
     def start_task_execution(
@@ -364,26 +363,26 @@ class DataSyncClient:
         Includes: List["FilterRuleTypeDef"] = None,
     ) -> StartTaskExecutionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.start_task_execution)
-        [Show boto3-stubs documentation](./client.md#start-task-execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.start_task_execution)
+        [Show boto3-stubs documentation](./client.md#start_task_execution)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: List["TagListEntryTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, Keys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_agent(self, AgentArn: str, Name: str = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.update_agent)
-        [Show boto3-stubs documentation](./client.md#update-agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.update_agent)
+        [Show boto3-stubs documentation](./client.md#update_agent)
         """
 
     def update_location_nfs(
@@ -394,23 +393,23 @@ class DataSyncClient:
         MountOptions: "NfsMountOptionsTypeDef" = None,
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.update_location_nfs)
-        [Show boto3-stubs documentation](./client.md#update-location-nfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.update_location_nfs)
+        [Show boto3-stubs documentation](./client.md#update_location_nfs)
         """
 
     def update_location_object_storage(
         self,
         LocationArn: str,
         ServerPort: int = None,
-        ServerProtocol: ObjectStorageServerProtocol = None,
+        ServerProtocol: ObjectStorageServerProtocolType = None,
         Subdirectory: str = None,
         AccessKey: str = None,
         SecretKey: str = None,
         AgentArns: List[str] = None,
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.update_location_object_storage)
-        [Show boto3-stubs documentation](./client.md#update-location-object-storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.update_location_object_storage)
+        [Show boto3-stubs documentation](./client.md#update_location_object_storage)
         """
 
     def update_location_smb(
@@ -424,8 +423,8 @@ class DataSyncClient:
         MountOptions: "SmbMountOptionsTypeDef" = None,
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.update_location_smb)
-        [Show boto3-stubs documentation](./client.md#update-location-smb)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.update_location_smb)
+        [Show boto3-stubs documentation](./client.md#update_location_smb)
         """
 
     def update_task(
@@ -438,28 +437,28 @@ class DataSyncClient:
         CloudWatchLogGroupArn: str = None,
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.update_task)
-        [Show boto3-stubs documentation](./client.md#update-task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.update_task)
+        [Show boto3-stubs documentation](./client.md#update_task)
         """
 
     def update_task_execution(
         self, TaskExecutionArn: str, Options: "OptionsTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Client.update_task_execution)
-        [Show boto3-stubs documentation](./client.md#update-task-execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Client.update_task_execution)
+        [Show boto3-stubs documentation](./client.md#update_task_execution)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_agents"]) -> ListAgentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListAgents)[Show boto3-stubs documentation](./paginators.md#listagentspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Paginator.ListAgents)[Show boto3-stubs documentation](./paginators.md#listagentspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_locations"]) -> ListLocationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListLocations)[Show boto3-stubs documentation](./paginators.md#listlocationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Paginator.ListLocations)[Show boto3-stubs documentation](./paginators.md#listlocationspaginator)
         """
 
     @overload
@@ -467,7 +466,7 @@ class DataSyncClient:
         self, operation_name: Literal["list_tags_for_resource"]
     ) -> ListTagsForResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)[Show boto3-stubs documentation](./paginators.md#listtagsforresourcepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)[Show boto3-stubs documentation](./paginators.md#listtagsforresourcepaginator)
         """
 
     @overload
@@ -475,11 +474,11 @@ class DataSyncClient:
         self, operation_name: Literal["list_task_executions"]
     ) -> ListTaskExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)[Show boto3-stubs documentation](./paginators.md#listtaskexecutionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)[Show boto3-stubs documentation](./paginators.md#listtaskexecutionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tasks"]) -> ListTasksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListTasks)[Show boto3-stubs documentation](./paginators.md#listtaskspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/datasync.html#DataSync.Paginator.ListTasks)[Show boto3-stubs documentation](./paginators.md#listtaskspaginator)
         """
