@@ -16,30 +16,30 @@ from datetime import datetime
 from typing import List
 
 from .literals import (
-    AgentStatus,
-    Atime,
-    EndpointType,
-    Gid,
-    LocationFilterName,
-    LogLevel,
-    Mtime,
-    NfsVersion,
-    ObjectStorageServerProtocol,
-    Operator,
-    OverwriteMode,
-    PhaseStatus,
-    PosixPermissions,
-    PreserveDeletedFiles,
-    PreserveDevices,
-    S3StorageClass,
-    SmbVersion,
-    TaskExecutionStatus,
-    TaskFilterName,
-    TaskQueueing,
-    TaskStatus,
-    TransferMode,
-    Uid,
-    VerifyMode,
+    AgentStatusType,
+    AtimeType,
+    EndpointTypeType,
+    GidType,
+    LocationFilterNameType,
+    LogLevelType,
+    MtimeType,
+    NfsVersionType,
+    ObjectStorageServerProtocolType,
+    OperatorType,
+    OverwriteModeType,
+    PhaseStatusType,
+    PosixPermissionsType,
+    PreserveDeletedFilesType,
+    PreserveDevicesType,
+    S3StorageClassType,
+    SmbVersionType,
+    TaskExecutionStatusType,
+    TaskFilterNameType,
+    TaskQueueingType,
+    TaskStatusType,
+    TransferModeType,
+    UidType,
+    VerifyModeType,
 )
 
 if sys.version_info >= (3, 8):
@@ -101,7 +101,7 @@ AgentListEntryTypeDef = TypedDict(
     {
         "AgentArn": str,
         "Name": str,
-        "Status": AgentStatus,
+        "Status": AgentStatusType,
     },
     total=False,
 )
@@ -175,10 +175,10 @@ DescribeAgentResponseTypeDef = TypedDict(
     {
         "AgentArn": str,
         "Name": str,
-        "Status": AgentStatus,
+        "Status": AgentStatusType,
         "LastConnectionTime": datetime,
         "CreationTime": datetime,
-        "EndpointType": EndpointType,
+        "EndpointType": EndpointTypeType,
         "PrivateLinkConfig": "PrivateLinkConfigTypeDef",
     },
     total=False,
@@ -227,7 +227,7 @@ DescribeLocationObjectStorageResponseTypeDef = TypedDict(
         "LocationUri": str,
         "AccessKey": str,
         "ServerPort": int,
-        "ServerProtocol": ObjectStorageServerProtocol,
+        "ServerProtocol": ObjectStorageServerProtocolType,
         "AgentArns": List[str],
         "CreationTime": datetime,
     },
@@ -239,7 +239,7 @@ DescribeLocationS3ResponseTypeDef = TypedDict(
     {
         "LocationArn": str,
         "LocationUri": str,
-        "S3StorageClass": S3StorageClass,
+        "S3StorageClass": S3StorageClassType,
         "S3Config": "S3ConfigTypeDef",
         "AgentArns": List[str],
         "CreationTime": datetime,
@@ -265,7 +265,7 @@ DescribeTaskExecutionResponseTypeDef = TypedDict(
     "DescribeTaskExecutionResponseTypeDef",
     {
         "TaskExecutionArn": str,
-        "Status": TaskExecutionStatus,
+        "Status": TaskExecutionStatusType,
         "Options": "OptionsTypeDef",
         "Excludes": List["FilterRuleTypeDef"],
         "Includes": List["FilterRuleTypeDef"],
@@ -284,7 +284,7 @@ DescribeTaskResponseTypeDef = TypedDict(
     "DescribeTaskResponseTypeDef",
     {
         "TaskArn": str,
-        "Status": TaskStatus,
+        "Status": TaskStatusType,
         "Name": str,
         "CurrentTaskExecutionArn": str,
         "SourceLocationArn": str,
@@ -367,9 +367,9 @@ ListTasksResponseTypeDef = TypedDict(
 LocationFilterTypeDef = TypedDict(
     "LocationFilterTypeDef",
     {
-        "Name": LocationFilterName,
+        "Name": LocationFilterNameType,
         "Values": List[str],
-        "Operator": Operator,
+        "Operator": OperatorType,
     },
 )
 
@@ -385,7 +385,7 @@ LocationListEntryTypeDef = TypedDict(
 NfsMountOptionsTypeDef = TypedDict(
     "NfsMountOptionsTypeDef",
     {
-        "Version": NfsVersion,
+        "Version": NfsVersionType,
     },
     total=False,
 )
@@ -400,19 +400,19 @@ OnPremConfigTypeDef = TypedDict(
 OptionsTypeDef = TypedDict(
     "OptionsTypeDef",
     {
-        "VerifyMode": VerifyMode,
-        "OverwriteMode": OverwriteMode,
-        "Atime": Atime,
-        "Mtime": Mtime,
-        "Uid": Uid,
-        "Gid": Gid,
-        "PreserveDeletedFiles": PreserveDeletedFiles,
-        "PreserveDevices": PreserveDevices,
-        "PosixPermissions": PosixPermissions,
+        "VerifyMode": VerifyModeType,
+        "OverwriteMode": OverwriteModeType,
+        "Atime": AtimeType,
+        "Mtime": MtimeType,
+        "Uid": UidType,
+        "Gid": GidType,
+        "PreserveDeletedFiles": PreserveDeletedFilesType,
+        "PreserveDevices": PreserveDevicesType,
+        "PosixPermissions": PosixPermissionsType,
         "BytesPerSecond": int,
-        "TaskQueueing": TaskQueueing,
-        "LogLevel": LogLevel,
-        "TransferMode": TransferMode,
+        "TaskQueueing": TaskQueueingType,
+        "LogLevel": LogLevelType,
+        "TransferMode": TransferModeType,
     },
     total=False,
 )
@@ -448,7 +448,7 @@ S3ConfigTypeDef = TypedDict(
 SmbMountOptionsTypeDef = TypedDict(
     "SmbMountOptionsTypeDef",
     {
-        "Version": SmbVersion,
+        "Version": SmbVersionType,
     },
     total=False,
 )
@@ -484,7 +484,7 @@ TaskExecutionListEntryTypeDef = TypedDict(
     "TaskExecutionListEntryTypeDef",
     {
         "TaskExecutionArn": str,
-        "Status": TaskExecutionStatus,
+        "Status": TaskExecutionStatusType,
     },
     total=False,
 )
@@ -493,12 +493,12 @@ TaskExecutionResultDetailTypeDef = TypedDict(
     "TaskExecutionResultDetailTypeDef",
     {
         "PrepareDuration": int,
-        "PrepareStatus": PhaseStatus,
+        "PrepareStatus": PhaseStatusType,
         "TotalDuration": int,
         "TransferDuration": int,
-        "TransferStatus": PhaseStatus,
+        "TransferStatus": PhaseStatusType,
         "VerifyDuration": int,
-        "VerifyStatus": PhaseStatus,
+        "VerifyStatus": PhaseStatusType,
         "ErrorCode": str,
         "ErrorDetail": str,
     },
@@ -508,9 +508,9 @@ TaskExecutionResultDetailTypeDef = TypedDict(
 TaskFilterTypeDef = TypedDict(
     "TaskFilterTypeDef",
     {
-        "Name": TaskFilterName,
+        "Name": TaskFilterNameType,
         "Values": List[str],
-        "Operator": Operator,
+        "Operator": OperatorType,
     },
 )
 
@@ -518,7 +518,7 @@ TaskListEntryTypeDef = TypedDict(
     "TaskListEntryTypeDef",
     {
         "TaskArn": str,
-        "Status": TaskStatus,
+        "Status": TaskStatusType,
         "Name": str,
     },
     total=False,
